#
# spec file for package elfutils
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           elfutils
Version:        0.168
Release:        4.5.3
Summary:        Higher-level library to access ELF files
License:        SUSE-GPL-2.0-with-OSI-exception
Group:          Development/Tools/Building
Url:            http://fedorahosted.org/elfutils/

#Git-Clone:	git://sourceware.org/git/elfutils
Source:         https://fedorahosted.org/releases/e/l/%{name}/%{version}/%{name}-%{version}.tar.bz2
Source4:        https://fedorahosted.org/releases/e/l/%{name}/%{version}/%{name}-%{version}.tar.bz2.sig
Source1:        README-BEFORE-ADDING-PATCHES
Source2:        baselibs.conf
Source3:        %{name}.changes
Patch1:         disable-tests-with-ptrace.patch
Patch2:         0001-backends-Add-support-for-EM_PPC64-GNU_ATTRIBUTES.patch
Patch3:         ppc-machine-flags.patch
Patch4:         elflint-sanity-check-the-number-of-phdrs-and-shdrs.patch
Patch5:         elfutils-dont-trust-sh_entsize.patch
Patch6:         libelf-error-if-elf_compress_gnu-is-used-on-SHF_COMPRESSED.patch
Patch7:         readelf-fix-off-by-one-sanity-check.patch
Patch8:         use-the-empty-string-for-note-names-with-zero-size.patch
Patch9:         elflint-dont-check-section-group-without-flags-word.patch
Patch10:        elflint-check-symbol-table-data-is-big-enough-before-check.patch
Patch11:        libelf-check-compression-before-allocate-output-buffer.patch
Patch12:        libdw-readelf-make-sure-there-is-enough-data-to-read.patch
Patch13:        libdw-check-end-of-attributes-list-consistently.patch
Patch14:        libdwfl-sanity-check-partial-core-file-data-reads.patch
Patch15:        arlib-check-that-sh_entsize-isnt-zero.patch
Patch16:        size-handle-recursive-elf-ar-files.patch
Patch17:        libdwfl-sanity-check-partial-core-file-dyn-data-read.patch
Patch18:        libebl-check-NT_PLATFORM-core-notes.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libbz2-devel
BuildRequires:  xz-devel
BuildRequires:  zlib-devel
Recommends:     %{name}.lang

%description
elfutils is a collection of utilities and libraries to read, create
and modify ELF binary files, find and handle DWARF debug data,
symbols, thread state and stacktraces for processes and core files.

%package -n libasm1
Summary:        A collection of utilities and DSOs to handle compiled objects
Group:          System/Libraries

%description -n libasm1
libasm contains the "asm" and "disasm" functions to assemble and
disassamble instructions. (There is only partial support for i686 and
BPF instructions.) This is part of the elfutils package.

%package -n libasm-devel
Summary:        A collection of utilities and DSOs to handle compiled objects
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libasm1 = %{version}

%description -n libasm-devel
This package contains the headers and libraries needed to build
applications that require libasm.

%package -n libebl-plugins
Summary:        Architecture backends for libebl
Group:          System/Libraries
Provides:       libebl = %{version}-%{release}
Obsoletes:      libebl < %{version}-%{release}
Provides:       libebl1 = %{version}-%{release}
Obsoletes:      libebl1 < %{version}-%{release}

%description -n libebl-plugins
This subpackage contains the plugins to read architecture-specific
debug info. This is part of the elfutils package.

%package -n libebl-devel
Summary:        Development files for libebl and for EBL plugins
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libdw-devel = %{version}

%description -n libebl-devel
This package contains the headers and libraries needed to build
applications that require libebl, or to build additional EBL
architecutre backend plugins.

%package -n libelf1
Summary:        Library to read and write ELF files
Group:          System/Libraries
Requires:       libebl-plugins = %{version}

%description -n libelf1
This package provides a high-level library to read and write ELF files.
This is part of the elfutils package.

%package -n libelf-devel
Summary:        Development files for libelf
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libelf1 = %{version}
Conflicts:      libelf0-devel

%description -n libelf-devel
This package contains the headers and libraries needed to build
applications that require libelf.

%package -n libdw1
Summary:        Library to access DWARF debugging information
Group:          System/Libraries

%description -n libdw1
This package provides a high-level library to access the DWARF debugging
information. This is part of the elfutils package.

%package -n libdw-devel
Summary:        Development files for libdw
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libdw1 = %{version}
Requires:       libelf-devel = %{version}

%description -n libdw-devel
This package contains the headers and libraries needed to build
applications that require libdw.

%lang_package

%prep
%setup -q
%if 0%{?qemu_user_space_build}
# qemu does not support ptrace
%patch1 -p1
%endif
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%build
# Change DATE/TIME macros to use last change time of elfutils.changes
# See http://lists.opensuse.org/opensuse-factory/2011-05/msg00304.html
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find . -type f -regex ".*\.c\|.*\.cpp\|.*\.h" -exec sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" {} +
# Set modversion used to verify dynamically loaded ebl backend matches to
# similarly predictable value [upstream default is hostname + date]
MODVERSION="suse-build `eval echo ${DATE} ${TIME}`"
sed --in-place "s/^MODVERSION=.*\$/MODVERSION=\"${MODVERSION}\"/" configure.ac
export CFLAGS="%optflags"
CFLAGS+=" -g" # make tests pass when user does not want debuginfo (boo#1031556)
%ifarch %sparc
# Small PIC model not sufficient
CFLAGS+=" -fPIC"
%endif
autoreconf -fi
%configure --program-prefix=eu-
make %{?_smp_mflags}

%install
make DESTDIR=$RPM_BUILD_ROOT install
# remove unneeded files
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
ls -lR $RPM_BUILD_ROOT%{_libdir}/libelf*
%find_lang %{name}

%post -n libasm1 -p /sbin/ldconfig

%post -n libelf1 -p /sbin/ldconfig

%post -n libdw1 -p /sbin/ldconfig

%postun -n libasm1 -p /sbin/ldconfig

%postun -n libelf1 -p /sbin/ldconfig

%postun -n libdw1 -p /sbin/ldconfig

%check
make check

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS NOTES README THANKS TODO
%{_bindir}/*

%files -n libasm1
%defattr(-,root,root)
%{_libdir}/libasm.so.*
%{_libdir}/libasm-%{version}.so

%files -n libasm-devel
%defattr(-,root,root)
%{_libdir}/libasm.so
%{_libdir}/libasm.a
%dir %{_includedir}/elfutils
%{_includedir}/elfutils/libasm.h

%files -n libebl-plugins
%defattr(-,root,root)
%{_libdir}/elfutils

%files -n libebl-devel
%defattr(-,root,root)
%{_libdir}/libebl.a
%dir %{_includedir}/elfutils
%{_includedir}/elfutils/libebl.h

%files -n libelf1
%defattr(-,root,root)
%{_libdir}/libelf.so.*
%{_libdir}/libelf-%{version}.so

%files -n libelf-devel
%defattr(-,root,root)
%{_libdir}/libelf.so
%{_libdir}/libelf.a
%{_includedir}/libelf.h
%{_includedir}/gelf.h
%{_includedir}/nlist.h
%dir %{_includedir}/elfutils
%{_includedir}/elfutils/elf-knowledge.h
%{_includedir}/elfutils/version.h
%{_libdir}/pkgconfig/libelf.pc

%files -n libdw1
%defattr(-,root,root)
%{_libdir}/libdw.so.*
%{_libdir}/libdw-%{version}.so

%files -n libdw-devel
%defattr(-,root,root)
%{_libdir}/libdw.a
%{_libdir}/libdw.so
%{_includedir}/dwarf.h
%dir %{_includedir}/elfutils
%{_includedir}/elfutils/libdw.h
%{_includedir}/elfutils/libdwelf.h
%{_includedir}/elfutils/libdwfl.h
%{_includedir}/elfutils/known-dwarf.h
%{_libdir}/pkgconfig/libdw.pc

%files lang -f %{name}.lang

%changelog
* Wed May 22 2019 jmoreira@suse.com
- CVE-2018-16402: libelf: denial of service/double free on an
  attempt to decompress the same section twice (bnc#1107066)
  Add patch:
  libelf-error-if-elf_compress_gnu-is-used-on-SHF_COMPRESSED.patch
- CVE-2018-18521: arlib: Divide-by-zero vulnerabilities in the
  function arlib_add_symbols() used by eu-ranlib (bnc#1112723)
  Add patch:
  arlib-check-that-sh_entsize-isnt-zero.patch
- CVE-2017-7611: elfutils: DoS (heap-based buffer over-read and
  application crash) via a crafted ELF file (bnc#1033088)
  Add patch:
  elflint-check-symbol-table-data-is-big-enough-before-check.patch
- CVE-2017-7610: elflint: heap-based buffer overflow in check_group
  (bnc#1033087)
  Add patch:
  elflint-dont-check-section-group-without-flags-word.patch
- CVE-2018-16403: heap buffer overflow in readelf (bnc#1107067)
  Add patch:
  libdw-check-end-of-attributes-list-consistently.patch
- CVE-2018-16062: heap-buffer-overflow in
  /elfutils/libdw/dwarf_getaranges.c:156 (bnc#1106390)
  Add patch:
  libdw-readelf-make-sure-there-is-enough-data-to-read.patch
- CVE-2018-18310: Invalid Address Read problem in
  dwfl_segment_report_module.c (bnc#1111973)
  Add patch:
  libdwfl-sanity-check-partial-core-file-data-reads.patch
- CVE-2019-7150: dwfl_segment_report_module doesn't check whether
  the dyn data read from core file is truncated (bnc#1123685)
  Add patch:
  libdwfl-sanity-check-partial-core-file-dyn-data-read.patch
- CVE-2019-7665: NT_PLATFORM core file note should be a zero
  terminated string (CVE is a bit misleading, as this is not a bug
  in libelf as described) (bnc#1125007)
  Add patch:
  libebl-check-NT_PLATFORM-core-notes.patch
- CVE-2017-7609: memory allocation failure in __libelf_decompress
  (bnc#1033086)
  Add patch:
  libelf-check-compression-before-allocate-output-buffer.patch
- CVE-2018-16402: Double-free crash in nm and readelf (bnc#1107066)
  Add patch:
  libelf-error-if-elf_compress_gnu-is-used-on-SHF_COMPRESSED.patch
- CVE-2017-7607: heap-based buffer overflow in handle_gnu_hashi
  (readelf.c) (bnc#1033084)
  Add patch:
  readelf-fix-off-by-one-sanity-check.patch
- CVE-2018-18520: eu-size: Bad handling of ar files inside are
  files (bnc#1112726)
  Add patch:
  size-handle-recursive-elf-ar-files.patch
- CVE-2017-7608: heap-based buffer overflow in
  ebl_object_note_type_name (eblobjnotetypename.c) (bnc#1033085)
  Add patch:
  use-the-empty-string-for-note-names-with-zero-size.patch
* Tue Sep 25 2018 jmoreira@suse.com
- CVE-2017-7613: elfutils: denial of service (memory consumption)
  via a crafted ELF file (bnc#1033090)
  Add patch:
  elflint-sanity-check-the-number-of-phdrs-and-shdrs.patch
- CVE-2017-7612: elfutils: denial of service (heap-based buffer
  over-read and application crash) via a crafted ELF file
  (bnc#1033089)
  Add patch: elfutils-dont-trust-sh_entsize.patch
* Sat Aug 26 2017 jengelh@inai.de
- Restore obsolete on libebl.
* Tue Aug  1 2017 jengelh@inai.de
- Update package descriptions.
- Rename libebl1 to libebl-plugins as these are not linked,
  but dlopened using their unversioned libebl_$ARCH.so name.
- Have libelf1 require libebl-plugins (libebl.a, which does the
  dlopen call, is staticly built into libelf1). This is necessary
  for pahole to display its results. [boo#1049871]
* Sun Jun 18 2017 schwab@linux-m68k.org
- ppc-machine-flags.patch: support EM_PPC machine flags
- disable-tests-with-ptrace.patch: disable more tests
* Sun May 28 2017 jengelh@inai.de
- Update Git-Clone URL
* Thu Apr 27 2017 mliska@suse.cz
- Add 0001-backends-Add-support-for-EM_PPC64-GNU_ATTRIBUTES.patch
  unconditionally in the spec file. As we can't support binary diff,
  a newly added test-case is removed from the patch.
* Tue Apr 25 2017 mliska@suse.cz
- Add 0001-backends-Add-support-for-EM_PPC64-GNU_ATTRIBUTES.patch:
  fix .gnu.attributes checking on ppc64{,le}.
* Fri Apr  7 2017 jengelh@inai.de
- Add missing ldconfig calls for libasm1
* Fri Mar 31 2017 bwiedemann@suse.com
- make tests pass when user does not want debuginfo (boo#1031556)
* Thu Mar 30 2017 rguenther@suse.com
- Update to version 0.168:
  libelf: gelf_newehdr and gelf_newehdr now return void *.
  libdw: dwarf.h corrected the DW_LANG_PLI constant name (was DW_LANG_PL1).
  readelf: Add optional --symbols[=SECTION] argument to select section name.
- Includes changes from 0001-Add-GCC7-Wimplicit-fallthrough-support-fixes.patch
  and 0001-ar-Fix-GCC7-Wformat-length-issues.patch.
- Remove elfutils-0.137-dwarf-header-check-fix.diff which is no longer
  required after a debugedit fix.
* Fri Dec  9 2016 mliska@suse.cz
- Add 0001-Add-GCC7-Wimplicit-fallthrough-support-fixes.patch: fix
  new warning introduced in GCC 7.
- Add 0001-ar-Fix-GCC7-Wformat-length-issues.patch: fix -Wformat-length
  warning introduced in GCC 7.
* Tue Aug 30 2016 matz@suse.com
- Update to version 0.167:
  libasm: Add eBPF disassembler for EM_BPF files.
  backends: Add m68k and BPF backends.
  ld: Removed.
  dwelf: Add ELF/DWARF string table creation functions. dwelf_strtab_init,
    dwelf_strtab_add, dwelf_strtab_add_len, dwelf_strtab_finalize,
    dwelf_strent_off, dwelf_strent_str and dwelf_strtab_free.
  Support compressed sections from binutils 2.27.
- Remove patch elfutils-0.166-elfcmp-comp-gcc6.patch: included upstream.
* Mon Jul 11 2016 schwab@suse.de
- disable-tests-with-ptrace.patch: disable tests that use ptrace when
  running under qemu-linux-user
* Mon Jun 27 2016 fcrozat@suse.com
- Update to version 0.166:
  + config: The default program prefix for the installed tools is now
  eu-. Use configure --program-prefix="" to not use a program
  prefix.
  + Various bugfixes.
- Drop elfutils-0.164-dt-ppc-opt.patch and
  elfutils-0.164-gcc6.patch (merged upstream)
- Add patch elfutils-0.166-elfcmp-comp-gcc6.patch: fix
  self-comparison error with GCC 6.
- Changes from 0.165:
  + Add eu-elfcompress
  + Add pkg-config files for libelf and libdw.
* Sat Apr 16 2016 normand@linux.vnet.ibm.com
-  add elfutils-0.164-gcc6.patch
* Sat Feb 27 2016 normand@linux.vnet.ibm.com
- rename dt-ppc-opt.patch as elfutils-0.164-dt-ppc-opt.patch
  and add reference to upstream commit id
* Tue Dec 15 2015 schwab@suse.de
- dt-ppc-opt.patch: add support for DT_PPC_OPT
* Fri Nov 20 2015 idonmez@suse.com
- Update to version 0.164
  Drop the following patches, fixed upstream:
  * elfutils-portability-0.163.patch
  * elfutils-revert-portability-scanf.patch
  * elfutils-uninitialized.diff
  * libebl-prototype-fix.diff
  Changelog:
  - strip, unstrip:
  * Handle ELF files with merged strtab/shstrtab tables.
  * Handle missing SHF_INFO_LINK section flags.
  - libelf:
  * Use int64_t for offsets in libelf.h instead of loff_t.
  - libdw:
  * dwarf.h Add preliminary DWARF5 DW_LANG_Haskell.
  - libdwfl:
  * dwfl_standard_find_debuginfo now searches any subdir of the binary
    path under the debuginfo root when the separate debug file couldn't
    be found by build-id.
  * dwfl_linux_proc_attach can now be called before any Dwfl_Modules
    have been reported.
- Implement %%check
* Fri Sep 11 2015 tonyj@suse.com
- Update to version 0.163
  Drop patch elfutils-fix-dir-traversal-vuln-in-ar-extraction.patch
  Drop patch elfutils-0.148-dont-crash.diff (fixed by 9ceebe69)
  Drop patch elfutils-portability-0.161.patch
  Add patch elfutils-portability-0.163.patch
  Changelog:
  0.163:
  - Bug fixes only, no new features.
  0.162:
  - libdw: Install new header elfutils/known-dwarf.h.
    dwarf.h Add preliminary DWARF5 constants DW_TAG_atomic_type,
    DW_LANG_Fortran03, DW_LANG_Fortran08. dwarf_peel_type now also
    handles DW_TAG_atomic_type.
  - addr2line: Input addresses are now always interpreted as hexadecimal
    numbers, never as octal or decimal numbers.
    New option -a, --addresses to print address before each entry.
    New option -C, --demangle to show demangled symbols.
    New option --pretty-print to print all information on one line.
  - ar: CVE-2014-9447 Directory traversal vulnerability in ar extraction.
  - backends: x32 support.
* Wed Feb 11 2015 tonyj@suse.com
- Make ebl modversion predictable to allow build-compare (bnc#916043)
* Wed Jan  7 2015 tonyj@suse.com
- CVE-2014-9447: elfutils: Directory traversal vulnerability (bnc#911662)
  Add patch: elfutils-fix-dir-traversal-vuln-in-ar-extraction.patch
* Wed Jan  7 2015 p.drouand@gmail.com
- Update to version 0.161
  + libdw: New function dwarf_peel_type. dwarf_aggregate_size now uses
    dwarf_peel_type to also provide the sizes of qualified types.
    dwarf_getmacros will now serve either of .debug_macro and
    .debug_macinfo transparently.  New interfaces
    dwarf_getmacros_off, dwarf_macro_getsrcfiles,
    dwarf_macro_getparamcnt, and dwarf_macro_param are available
    for more generalized inspection of macros and their parameters.
    dwarf.h: Add DW_AT_GNU_deleted, DW_AT_noreturn, DW_LANG_C11,
    DW_LANG_C_plus_plus_11 and DW_LANG_C_plus_plus_14.
- Remove merged patches
  + elfutils-robustify.patch
  + elfutils-no-po-test-build.diff
  + elfutils-check-for-overflow-before-calling-malloc-to-uncompress-data.patch
- Refreshed patch (from Fedora sources)
  + elfutils-portability.patch > elfutils-portability-0.161.patch
- Add a lang subpackage
* Wed Oct 15 2014 jengelh@inai.de
- Update homepage URL and improve RPM group classification
* Thu Jun 19 2014 tonyj@suse.com
- Package changes file to support local rpmbuild (bnc#879011)
* Tue Apr 15 2014 tonyj@suse.com
- Fix integer overflow in check_section (CVE-2014-0172, bnc#872785)
  Add patch: elfutils-check-for-overflow-before-calling-malloc-to-uncompress-data.patch
* Sat Mar 22 2014 jengelh@inai.de
- SPARC build requires the large PIC model (or else build fails)
* Tue Jan 28 2014 tonyj@suse.com
- Update to 0.158:
  - libdwfl:
  - dwfl_core_file_report has new parameter executable.
  - New functions dwfl_module_getsymtab_first_global,
    dwfl_module_getsym_info and dwfl_module_addrinfo.
  - Added unwinder with type Dwfl_Thread_Callbacks, opaque types
    Dwfl_Thread and Dwfl_Frame and functions dwfl_attach_state,
    dwfl_pid, dwfl_thread_dwfl, dwfl_thread_tid, dwfl_frame_thread,
    dwfl_thread_state_registers, dwfl_thread_state_register_pc,
    dwfl_getthread_frames, dwfl_getthreads, dwfl_thread_getframes
    and dwfl_frame_pc.
  - addr2line: New option -x to show the section an address was found in.
  - stack: New utility that uses the new unwinder for processes and cores.
  - backends: Unwinder support for i386, x86_64, s390, s390x, ppc and ppc64.
    aarch64 support.
* Wed Nov 13 2013 sweet_f_a@gmx.de
- update to 0.157:
  libdw: Add new functions dwarf_getlocations, dwarf_getlocation_attr
    and dwarf_getlocation_die.
  readelf: Show contents of NT_SIGINFO and NT_FILE core notes.
  addr2line: Support -i, --inlines output option.
  backends: abi_cfi hook for arm, ppc and s390.
- update to 0.156:
  lib: New macro COMPAT_VERSION_NEWPROTO.
  libdw: Handle GNU extension opcodes in dwarf_getlocation.
  libdwfl: Fix STB_GLOBAL over STB_WEAK preference in dwfl_module_addrsym.
    Add minisymtab support.
    Add parameter add_p_vaddr to dwfl_report_elf.
    Use DT_DEBUG library search first.
  libebl: Handle new core note types in EBL.
  backends: Interpret NT_ARM_VFP.
    Implement core file registers parsing for s390/s390x.
  readelf: Add --elf-section input option to inspect an embedded ELF file.
    Add -U, --unresolved-address-offsets output control.
    Add --debug-dump=decodedline support.
    Accept version 8 .gdb_index section format.
    Adjust output formatting width.
    When highpc is in constant form print it also as address.
    Display raw .debug_aranges. Use libdw only for decodedaranges.
  elflint: Add __bss_start__ to the list of allowed symbols.
  tests: Add configure --enable-valgrind option to run all tests under valgrind.
    Enable automake parallel-tests for make check.
  translations: Updated Polish translation.
  Updates for Automake 1.13.
- remove elfutils-aarch64.patch and elfutils-sizeof-pointer-memaccess.patch
  (fixed by upstream)
- rebase elfutils-robustify.patch and elfutils-portability.patch, they are
  provided by ustream
* Tue Jun 18 2013 schwab@suse.de
- elfutils-sizeof-pointer-memaccess.patch: Fix sizeof-pointer-memaccess
  warnings
* Tue Mar 26 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Wed Nov 28 2012 adrian@suse.de
- add elfutils-aarch64.patch to support aarch64
- update to 0.155
  libelf: elf*_xlatetomd now works for cross-endian ELF note data.
  elf_getshdr now works consistently on non-mmaped ELF files after
  calling elf_cntl(ELF_C_FDREAD).
  Implement support for ar archives with 64-bit symbol table.
  [g]elf[32|64]_offscn() do not match SHT_NOBITS sections at OFFSET.
  libdw: dwarf.h corrected the DW_LANG_ObjC constant name (was DW_LANG_Objc).
    Any existing sources using the old name will have to be updated.
    Add DW_MACRO_GNU .debug_macro type encodings constants, DW_ATE_UTF
    and DW_OP_GNU_parameter_ref to dwarf.h.
    Experimental support for DWZ multifile forms DW_FORM_GNU_ref_alt
    and DW_FORM_GNU_strp_alt.  Disabled by default.  Use configure
  - -enable-dwz to test it.
    dwarf_highpc function now handles DWARF 4 DW_AT_high_pc constant form.
    Fix bug using dwarf_next_unit to iterate over .debug_types.
  elflint: Now accepts gold linker produced executables.
  readelf: Add .debug_macro parsing support.
  Add .gdb_index version 7 parsing support.
  Recognize DW_OP_GNU_parameter_ref.
  backends: Add support for Tilera TILE-Gx processor.
  translations: Updated Ukrainian translation.
  The license is now GPLv2/LGPLv3+ for the libraries and GPLv3+ for stand-alone
  programs. There is now also a formal CONTRIBUTING document describing how to
  submit patches.
* Mon Oct  8 2012 schwab@linux-m68k.org
- Fix baselibs.conf: elfutils-devel -> libelf-devel
* Thu Sep 20 2012 cfarrell@suse.com
- license update: SUSE-GPL-2.0-with-OSI-exception
  Use a license available on the spreadsheet linked at
  license.opensuse.org
* Wed May 30 2012 sweet_f_a@gmx.de
- avoid automake dependency
* Thu Mar 15 2012 aj@suse.de
- Update to 0.153:
  * Fix building with gcc 4.7
  * New --disable-werror for portability.
  * Support for .zdebug sections
  * type_units and DW_AT_GNU_odr_signature support
  * low level support DW_OP_GNU_entry_value and DW_TAG_GNU_call_site
- Revert scanf changes in portability patch since C99 gives %%a a new
  meaning.
* Fri Dec  2 2011 cfarrell@suse.com
- license update: GPL-2.0-with-osi-exception
  elfutils is GPL-2.0 (only) with an exception for osi approved licenses.
  Also, use SPDX format
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Add elfutils-devel to baselibs
* Tue May 24 2011 crrodriguez@opensuse.org
- Remote timestamps on binaries, breaks build compare
- Add missing build requires on zlib, bzip2 and lzma .
* Wed Apr 27 2011 tonyj@novell.com
- Upgrade to 0.152, upstream changelog:
  - Various build and warning nits fixed for newest GCC and Autoconf.
  - libdwfl: Yet another prelink-related fix for another regression.
    Look for Linux kernel images in files named with compression
    suffixes.
  - elfcmp: New flag --ignore-build-id to ignore differing build ID bits.
  New flag -l/--verbose to print all differences.
* Fri Jan 21 2011 tonyj@novell.com
- Update to 0.151
- Upstream changelog for 0.151/0.150
  - libdwfl: Fix for more prelink cases with separate debug file.
  - eu-strip: New flag --strip-sections to remove section headers entirely.
  - libdwfl: Remove bogus assert.
  - libdw: Fix for handling huge .debug_aranges section.
  - libdwfl: Fix for handling prelinked DSO with separate debug file.
  - findtextrel: Fix diagnostics to work with usual section ordering.
  - libebl: i386 backend fix for multi-register integer return value location
* Sat Sep 18 2010 tonyj@novell.com
- Update to 0.149
- Upstream changelog
  - libdwfl: Fix Linux kernel module search when dwfl_build_id_find_elf and
    dwfl_build_id_find_debuginfo close fd on success
  - readelf: Use symbolic printing for FDE initial_location address
  - readelf: Print .debug_loc/.debug_ranges with cognizance of actual DIE
    pointers into them.
  - readelf: Fix crash in .debug_loc with garbage data.
  - readelf: Fix DW_OP_call_ref printing for version 2 CUs.
  - Handle DW_OP_GNU_implicit_pointer.
  - Add dwfl_dwarf_line, addr2line -F to print out more line info bits.
  - Add missing size entries for ELF_T_LIB and ELF_T_GNUHASH.
  - Fix dwarf_formref_die DW_FORM_ref_sig8 hash table insertion.
  - Consider .gdb_index as a debugging section
  - Misc intendation, typo, translation and cleanup fixes
* Mon Sep 13 2010 coolo@novell.com
- add small patch to avoid crash in systemtap while building preload
* Thu Aug 26 2010 tonyj@suse.de
- Update to 0.148
- Upstream changelog
  - libdw: Accept DWARF 4 format: new functions dwarf_next_unit,
    dwarf_offdie_types.  New functions dwarf_lineisa,
    dwarf_linediscriminator, dwarf_lineop_index.
  - libdwfl: Fixes in core-file handling, support cores from PIEs.
    When working from build IDs, don't open a named file that mismatches.
  - readelf: Handle DWARF 4 formats.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Tue May 11 2010 tonyj@novell.com
- update to version 0.147 (fix bnc#588293)
- dropped patches for 10.3 and older
- dropped elfutils-0.97-ftruncate-mmap-fix, libelf-ignore-NOBITS, test and
  build patches. According to jbl these were mistakenly checked in from
  home:janblunck:debuginfo:libs/elfutils and the purpose of this project is
  no longer known. Absense of any patch header makes confirmation difficult.
- Upstream changelog:
  0.147
  - libdw: Fixes in CFI handling, best possible handling of bogus CFA
    ops.
  - libdwfl: Ignore R_*_NONE relocs, works around old (binutils) ld -r
    bugs.
  0.146
  - libdwfl: New function dwfl_core_file_report.
  0.145
  - Fix build with --disable-dependency-tracking.
  - Fix build with most recent glibc headers.
  - libelf: More robust to bogus section headers.
  - libdw: Fix CFI decoding.
  - libdwfl: Fix address bias returned by CFI accessors.   Fix core
    file module layout identification.
  - readelf: Fix CFI decoding.
  0.144
  - libelf: New function elf_getphdrnum.  Now support using more than
    65536 program headers in a file.
  - libdw: New function dwarf_aggregate_size for computing (constant)
    type        sizes, including array_type cases with nontrivial
    calculation.
  - readelf: Don't give errors for missing info under -a.
    Handle Linux "VMCOREINFO" notes under -n.
  0.143
  - libdw: Various convenience functions for individual attributes now
    use dwarf_attr_integrate to look up indirect inherited
    attributes.  Location expression handling now supports
    DW_OP_implicit_value.
  - libdwfl: Support automatic decompression of files in XZ format,
    and of Linux kernel images made with bzip2 or LZMA (as well
    as gzip).
* Wed Feb 10 2010 rguenther@suse.de
- Fix uninitialized variable.
* Sat Dec 12 2009 jengelh@medozas.de
- Enable parallel building
- add baselibs.conf as a source
* Thu Aug 20 2009 rguenther@suse.de
- Fix elfutils-old-scanf-fix.diff patch.
* Thu Aug 13 2009 tiwai@suse.de
- updated to 0.142:
  - Fix handling filling caps between sections in libelf
  - Add elf_getshdrnum alias for elf_getshnum and elf_getshdrstrndx
    alias for elf_getshstrndx and deprecate original names.
  - Add support for STB_GNU_UNIQUE
  - Add -N option to readelf, speeds up DWARF printing without
    address->name lookups
  - Add support for decoding DWARF CFI into location description
    form to libdw.
    Some new DWARF 3 expression operations.
    Basic handling of some new encodings slated for DWARF 4.
* Wed Apr 29 2009 tiwai@suse.de
- updated to 0.141:
  - libebl: sparc backend fixes
    some more arm backend support
  - libdwfl: fix dwfl_module_build_id for prelinked DSO case
    fixes in core file support dwfl_module_getsym interface
    improved for non-address symbols
  - eu-strip: fix infinite loop on strange inputs with -f
  - eu-addr2line: take -j/--section=NAME option for binutils
    compatibility (same effect as '(NAME)0x123' syntax already
    supported)
* Thu Feb 19 2009 tiwai@suse.de
- Update to 0.139
  - libcpu: Add Intel SSE4 disassembler support
  - readelf: Implement call frame information and exception
    handling dumping.
    Add -e option.  Enable it implicitly for -a.
  - elflint: Check PT_GNU_EH_FRAME program header entry.
  - libdwfl: Support automatic gzip/bzip2 decompression of ELF
    files.
- updated to 0.140:
  - libelf: Fix regression in creation of section header.
  - Misc bug fixes
* Tue Jan 27 2009 tiwai@suse.de
- revert the ET_DYN address fix patch; causing a regression
  (bnc#468814)
* Wed Jan  7 2009 tiwai@suse.de
- Fix the header size check in dwarf_getsrclines() (bnc#455992)
- Backport the fix for ET_DYN addresses
* Tue Dec 16 2008 tiwai@suse.de
- Fix dwfl_getmodules(), assert in systemtap (bnc#448331)
- Fix libebl1 dependency
- Fix crashes of elfutils binaries, backports from upstream
* Tue Nov 25 2008 tiwai@suse.de
- fix libdwfl regression with realloc DWFL->lookup_module in
  the fix patch (bnc#448331, likely bnc#445783)
* Tue Oct 28 2008 tiwai@suse.de
- added baselibs.conf for 32bit libs (bnc#439582)
* Tue Oct  7 2008 tiwai@suse.de
- renamed to libebl1
- provides libasm1 package
- fix provides and obsolets of libebl1
- updated to version 0.137:
  * libdwfl: bug fixes
* Tue Aug 26 2008 tiwai@suse.de
- updated to version 0.135:
  * libdwfl: bug fixes
- updated to version 0.134:
  * libdwfl, libelf: bug fixes
- updated to version 0.133:
  * readelf, elflint, libebl: SHT_GNU_ATTRIBUTE section handling
    (readelf -A)
  * libdwfl: bug fixes and optimization in relocation handling
- updated to version 0.132:
  * libcpu: Implement x86 and x86-64 disassembler.
  * libasm: Add interface for disassembler.
- fixed post scripts
* Fri Feb 29 2008 dmueller@suse.de
- fix build for older distributions
* Mon Jan 28 2008 tiwai@suse.de
- fix compile errors regarding missing prototypes.
* Tue Nov 20 2007 tiwai@suse.de
- fix off64_t in libelf.h again...
* Tue Nov 20 2007 tiwai@suse.de
- updated to version 0.131
  * libdw: DW_FORM_ref_addr support
    dwarf_formref entry point now deprecated
    bug fixes for oddly-formatted DWARF
  * libdwfl: bug fixes in offline archive support
    apply partial relocations for dwfl_module_address_section
    on ET_REL
  * libebl: powerpc backend support for Altivec registers
* Mon Oct 22 2007 tiwai@suse.de
- fix comiple errors regarding missing off64_t definitions
  in libelf.h
* Mon Oct 22 2007 tiwai@suse.de
- updated to version 0.129:
  readelf: new options --hex-dump (or -x), --strings (or -p)
- updated to version 0.130
  * readelf: -p option can take an argument like -x for one
    section
  * libelf: new function elf_getdata_rawchunk, replaces
    gelf_rawchunk;
    new functions gelf_getnote, gelf_getauxv, gelf_update_auxv
  * libdwfl: new functions dwfl_build_id_find_elf,
    dwfl_build_id_find_debuginfo, dwfl_module_build_id,
    dwfl_module_report_build_id;
    support dynamic symbol tables found via phdrs;
    dwfl_standard_find_debuginfo now uses build IDs when available
  * libebl: backend improvements for sparc, alpha, powerpc
* Thu Oct  4 2007 rguenther@suse.de
- fix build with gcc-4.3, same patch as for the copy in rpm
* Wed Jul  4 2007 tiwai@suse.de
- updated to version 0.128
  * auto-tool fixes
* Sun Jun 10 2007 ro@suse.de
- use __attribute__ ((gnu_inline)) to fix build with gcc-4.2
* Mon May 21 2007 tiwai@suse.de
- initial packages, built from elfutils-0.127.
  A problematic file regarding the license is removed from the
  tarball.
